# file-transformer Python Library

The Datanet Python Library provides convenient access to the file-transformer API from applications written in the Python language.

## installation

If you just want to use the package, just run:

```sh
pip install --upgrade file_transformer
```
